@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,7 +68,7 @@ import com.openexchange.contacts.ldap.ldap.LdapGetter;
 import com.openexchange.contacts.ldap.ldap.LdapInterface;
 import com.openexchange.contacts.ldap.ldap.LdapJNDIImpl;
 import com.openexchange.contacts.ldap.ldap.LdapInterface.FillClosure;
-import com.openexchange.contacts.ldap.osgi.ServiceRegistry;
+import com.openexchange.contacts.ldap.osgi.LDAPServiceRegistry;
 import com.openexchange.contacts.ldap.property.FolderProperties;
 import com.openexchange.contacts.ldap.property.Mappings;
 import com.openexchange.contacts.ldap.property.FolderProperties.ContactTypes;
@@ -93,7 +93,7 @@ public class LdapContactInterface implements ContactInterface {
 
     private class ContactLoaderTask implements Runnable {
         
-        private final LdapContactInterfaceProvider contactIFace;
+        private final LdapContactInterfaceProvider _contactIFace;
         
         private final Set<Integer> columns;
         
@@ -101,7 +101,7 @@ public class LdapContactInterface implements ContactInterface {
 
         public ContactLoaderTask(final LdapContactInterfaceProvider contactIFace, final int folderId, final Set<Integer> columns) {
             super();
-            this.contactIFace = contactIFace;
+            this._contactIFace = contactIFace;
             this.folderId = folderId;
             this.columns = columns;
         }
@@ -109,11 +109,11 @@ public class LdapContactInterface implements ContactInterface {
         public void run() {
             try {
                 final List<Contact> ldapContacts = getLDAPContacts(folderId, columns, null, null, null, false);
-                this.contactIFace.rwlock_cached_contacts.writeLock().lock();
+                this._contactIFace.rwlock_cached_contacts.writeLock().lock();
                 try {
-                    this.contactIFace.cached_contacts = ldapContacts;
+                    this._contactIFace.cached_contacts = ldapContacts;
                 } finally {
-                    this.contactIFace.rwlock_cached_contacts.writeLock().unlock();
+                    this._contactIFace.rwlock_cached_contacts.writeLock().unlock();
                 }
             } catch (final LdapException e) {
                 LOG.error(e.getMessage(), e);
@@ -125,7 +125,7 @@ public class LdapContactInterface implements ContactInterface {
 
     private static final ArrayIterator<Contact> EMPTY_ARRAY_ITERATOR = new ArrayIterator<Contact>(new Contact[0]);
 
-    public class SortInfo {
+    public static final class SortInfo {
 
         private final int field;
 
@@ -245,16 +245,16 @@ public class LdapContactInterface implements ContactInterface {
     public SearchIterator<Contact> getContactsByExtendedSearch(final ContactSearchObject searchobject, final int orderBy, final String orderDir, final int[] cols) throws OXException {
         final Order valueOf = getOrder(orderDir);
         final Set<Integer> columns = getColumnSet(cols);
-        final int[] folders = searchobject.getFolders();
         final int folderId;
-        if (null != folders) {
-            if (folders.length == 1) {
-                folderId = folders[0];
-            } else {
+        {
+            final int[] folders = searchobject.getFolders();
+            if (null == folders) {
+                throw new LdapException(Code.FOLDERID_OBJECT_NULL);
+            }
+            if (folders.length != 1) {
                 throw new LdapException(Code.TOO_MANY_FOLDERS);
             }
-        } else {
-            throw new LdapException(Code.FOLDERID_OBJECT_NULL);
+            folderId = folders[0];
         }
         final ArrayList<Contact> arrayList;
 
@@ -306,11 +306,11 @@ public class LdapContactInterface implements ContactInterface {
         
         final Set<Integer> columns = getColumnSet(cols);
         if (0 == orderBy) {
-            columns.add(Contact.SUR_NAME);
-            columns.add(Contact.DISPLAY_NAME);
-            columns.add(Contact.COMPANY);
-            columns.add(Contact.EMAIL1);
-            columns.add(Contact.EMAIL2);
+            columns.add(Integer.valueOf(Contact.SUR_NAME));
+            columns.add(Integer.valueOf(Contact.DISPLAY_NAME));
+            columns.add(Integer.valueOf(Contact.COMPANY));
+            columns.add(Integer.valueOf(Contact.EMAIL1));
+            columns.add(Integer.valueOf(Contact.EMAIL2));
         }
         if (0 != orderBy) {
             columns.addAll(getColumnSet(new int[]{orderBy}));
@@ -330,7 +330,7 @@ public class LdapContactInterface implements ContactInterface {
                     this.contactIFace.rwlock_cached_contacts.writeLock().unlock();
                 }
                 // Start thread
-                ServiceRegistry.getInstance().getService(TimerService.class).scheduleWithFixedDelay(new ContactLoaderTask(this.contactIFace, folderId, columns), folderprop.getRefreshinterval(), folderprop.getRefreshinterval());
+                LDAPServiceRegistry.getInstance().getService(TimerService.class).scheduleWithFixedDelay(new ContactLoaderTask(this.contactIFace, folderId, columns), folderprop.getRefreshinterval(), folderprop.getRefreshinterval());
             } else {
                 try {
                     try {
@@ -456,6 +456,10 @@ public class LdapContactInterface implements ContactInterface {
         LOG.info("Called updateContactObject");
     }
 
+    public void updateUserContact(Contact contact, Date lastmodified) throws OXException {
+        LOG.info("Called updateUserContact");
+    }
+
     private void addFilterFor(final String fieldname, final String searchString, final StringBuilder sb) {
         if ("*".equals(searchString)) {
             sb.append("(");
@@ -523,7 +527,7 @@ public class LdapContactInterface implements ContactInterface {
     }
 
 
-    private ArrayList<Contact> getLDAPContacts(final int folderId, final Set<Integer> columns, final String usersearchfilter, final String distributionsearchfilter, final SortInfo sortField, final boolean deleted) throws LdapException {
+    ArrayList<Contact> getLDAPContacts(final int folderId, final Set<Integer> columns, final String usersearchfilter, final String distributionsearchfilter, final SortInfo sortField, final boolean deleted) throws LdapException {
         final ArrayList<Contact> arrayList = new ArrayList<Contact>();
         final boolean both = ContactTypes.both.equals(folderprop.getContacttypes());
         final boolean distributionlist = both || ContactTypes.distributionlists.equals(folderprop.getContacttypes());
